@@ -4,6 +4,7 @@
 
 import json
 from logging import getLogger
+from enum import IntEnum
 from typing import List, Optional
 import signal
 import requests
@@ -37,7 +38,7 @@ EXEC_ACTION = "execaction"
 HEADERS = {"Accept": "application/json"}
 HOST = "host"
 JSON = "json"
-REQ_FORMAT = "fmt"
+REQ_FORMAT = "format"
 STOP_ON_ERROR = "stopOnError"
 TIMEOUT_CLI = "timeout"
 TIMEOUT_CONN = "connTimeout"
@@ -46,6 +47,15 @@ USERNAME = "username"
 systemLogger = getLogger(__name__)
 
 
+class LoggingLevel(IntEnum):
+    Trace = 0,
+    Debug = 1,
+    Info = 2,
+    Warn = 3,
+    Error = 4,
+    Critical = 5
+
+
 class Context:
     '''
     Context object that stores a number of system and user-defined parameters:
@@ -66,7 +76,8 @@ class Context:
                  studio: Optional[Studio] = None,
                  execution: Optional[Execution] = None,
                  connections: Optional[AuthAndEndpoints] = None,
-                 logger: Optional[Logger] = None):
+                 logger: Optional[Logger] = None,
+                 loggingLevel: Optional[LoggingLevel] = None):
         self.user = user
         self.device = device
         self.action = action
@@ -84,6 +95,7 @@ class Context:
         self.__serviceChann = None
         self.topology: Optional[Topology] = None
         self.preserveWhitespace = False
+        self.loggingLevel = loggingLevel if loggingLevel else LoggingLevel.Info
 
     def getDevice(self):
         '''
@@ -401,21 +413,54 @@ If calling store without a path, please provide a studio or changeControl object
         self.logger.alog(self, message, userName, customKey)
 
     def trace(self, msg):
+        """
+        Creates a trace level log if the context's logging level is set to allow for it
+        If the logging level is higher, is a no-op
+        """
+        if self.getLoggingLevel() > LoggingLevel.Trace:
+            return
         self.logger.trace(self, msg)
 
     def debug(self, msg):
+        """
+        Creates a debug level log if the context's logging level is set to allow for it
+        If the logging level is higher, is a no-op
+        """
+        if self.getLoggingLevel() > LoggingLevel.Debug:
+            return
         self.logger.debug(self, msg)
 
     def info(self, msg):
+        """
+        Creates an info level log if the context's logging level is set to allow for it
+        If the logging level is higher, is a no-op
+        """
+        if self.getLoggingLevel() > LoggingLevel.Info:
+            return
         self.logger.info(self, msg)
 
     def warning(self, msg):
+        """
+        Creates a warning level log if the context's logging level is set to allow for it
+        If the logging level is higher, is a no-op
+        """
+        if self.getLoggingLevel() > LoggingLevel.Warn:
+            return
         self.logger.warning(self, msg)
 
     def error(self, msg):
-        self.logger.warning(self, msg)
+        """
+        Creates an error level log if the context's logging level is set to allow for it
+        If the logging level is higher, is a no-op
+        """
+        if self.getLoggingLevel() > LoggingLevel.Error:
+            return
+        self.logger.error(self, msg)
 
     def critical(self, msg):
+        """
+        Creates a critical level log
+        """
         self.logger.critical(self, msg)
 
     def keepBlankLines(self, preserve=True):
@@ -424,6 +469,30 @@ If calling store without a path, please provide a studio or changeControl object
         # clean rendered templates post-rendering
         self.preserveWhitespace = preserve
 
+    def setLoggingLevel(self, loggingLevel: LoggingLevel):
+        """
+        Takes a logging level value and applies it for use in logging call checks
+        """
+        self.loggingLevel = loggingLevel
+
+    def getLoggingLevel(self):
+        """
+        Gets the current logging level of the context
+        """
+        return self.loggingLevel
+
+    def activateDebugMode(self):
+        """
+        Activates debug logging by setting the logging level to debug
+        """
+        self.loggingLevel = LoggingLevel.Debug
+
+    def deactivateDebugMode(self):
+        """
+        Deactivates debug logging by setting the logging level to info
+        """
+        self.loggingLevel = LoggingLevel.Info
+
     # In the case where the context has no logger defined,
     # we can create a compatible backup logger using the system logger
     # This is called in init if no logger is provided
